@@ -1,10 +1,10 @@
 /*
  * Program name:  equake
- * Version:	  1.03.8
+ * Version:	  1.3.8.1
  * Source file:	  equake_applet.c  
  * Description:	  Equake pulls data about earthquakes and displays it in interesting ways
  *
- * Copyright (C) 2012-2015 Jeroen van Aart
+ * Copyright (C) 2012-2017 Jeroen van Aart
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,8 +30,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <curl/curl.h>
 #include <sys/types.h>
-#include <sys/socket.h>
 #include <pwd.h>
 #include <netinet/in.h>
 #include <netdb.h>
@@ -967,10 +967,10 @@ static void fill_text_period(struct Equake_Data *equakedata, char *running, char
     for (n=0;n<=equakedata->quake_history_countdaily;n++)
     {
       /* create url to be displayed */
-      snprintf(url, URLSIZE, "%s%s%s%s%s", "http://", equakedata->quakeserver, equakedata->quakepath_ww, equakedata->equakeformatday[n].eqid, QUAKEPATH_AF);
+      snprintf(url, URLSIZE, "%s://%s%s%s%s", equakedata->portname, equakedata->quakeserver, equakedata->quakepath_ww, equakedata->equakeformatday[n].eqid, QUAKEPATH_AF);
       /* create map url */
-      snprintf(mapurl, URLSIZE, "%s%s%s%s%s%s%s%s%s%s%s%s%s%s", "http://", MAPURL1, equakedata->equakeformatday[n].lat, MAPURL2, equakedata->equakeformatday[n].lon, MAPURL2, "Earthquake Magnitude: ", equakedata->equakeformatday[n].magnitude, " Region: ", equakedata->equakeformatday[n].region, MAPURL2, "Rendered by e-quake.org", MAPURL2, WEBSITE);
-
+      snprintf(mapurl, URLSIZE, "%s://%s%s%s%s%s%s%s%s%s%s%s%s%s", equakedata->portname, MAPURL1, equakedata->equakeformatday[n].lat, MAPURL2, equakedata->equakeformatday[n].lon, MAPURL2, "Earthquake Magnitude: ", equakedata->equakeformatday[n].magnitude, " Region: ", equakedata->equakeformatday[n].region, MAPURL2, "Rendered by e-quake.org", MAPURL2, WEBSITE);
+      
       /* convert magnitude to double */
       if(equakedata->equakeformatday[n].magnitude!=NULL)
         mag=atof(equakedata->equakeformatday[n].magnitude);
@@ -1003,9 +1003,9 @@ static void fill_text_period(struct Equake_Data *equakedata, char *running, char
       for (n=0;n<=equakedata->quake_history_countweekly;n++)
       {
         /* create url to be displayed */
-        snprintf(url, URLSIZE, "%s%s%s%s%s", "http://", equakedata->quakeserver, equakedata->quakepath_ww, equakedata->equakeformatweek[n].eqid, QUAKEPATH_AF);
+        snprintf(url, URLSIZE, "%s://%s%s%s%s", equakedata->portname, equakedata->quakeserver, equakedata->quakepath_ww, equakedata->equakeformatweek[n].eqid, QUAKEPATH_AF);
         /* create map url */
-        snprintf(mapurl, URLSIZE, "%s%s%s%s%s%s%s%s%s%s%s%s%s%s", "http://", MAPURL1, equakedata->equakeformatweek[n].lat, MAPURL2, equakedata->equakeformatweek[n].lon, MAPURL2, "Earthquake Magnitude: ", equakedata->equakeformatweek[n].magnitude, " Region: ", equakedata->equakeformatweek[n].region, MAPURL2, "Rendered by e-quake.org", MAPURL2, WEBSITE);
+        snprintf(mapurl, URLSIZE, "%s://%s%s%s%s%s%s%s%s%s%s%s%s%s", equakedata->portname, MAPURL1, equakedata->equakeformatweek[n].lat, MAPURL2, equakedata->equakeformatweek[n].lon, MAPURL2, "Earthquake Magnitude: ", equakedata->equakeformatweek[n].magnitude, " Region: ", equakedata->equakeformatweek[n].region, MAPURL2, "Rendered by e-quake.org", MAPURL2, WEBSITE);
 
         /* convert magnitude to double */
         if(equakedata->equakeformatweek[n].magnitude!=NULL)
@@ -1037,9 +1037,9 @@ static void fill_text_period(struct Equake_Data *equakedata, char *running, char
       for (n=0;n<=equakedata->quake_history_count;n++)
       {
         /* create url to be displayed */
-        snprintf(url, URLSIZE, "%s%s%s%s%s", "http://", equakedata->quakeserver, equakedata->quakepath_ww, equakedata->equakeformat[n].eqid, QUAKEPATH_AF);
+        snprintf(url, URLSIZE, "%s://%s%s%s%s", equakedata->portname, equakedata->quakeserver, equakedata->quakepath_ww, equakedata->equakeformat[n].eqid, QUAKEPATH_AF);
 	/* create map url */
-        snprintf(mapurl, URLSIZE, "%s%s%s%s%s%s%s%s%s%s%s%s%s%s", "http://", MAPURL1, equakedata->equakeformat[n].lat, MAPURL2, equakedata->equakeformat[n].lon, MAPURL2, "Earthquake Magnitude: ", equakedata->equakeformat[n].magnitude, " Region: ", equakedata->equakeformat[n].region, MAPURL2, "Rendered by e-quake.org", MAPURL2, WEBSITE);
+        snprintf(mapurl, URLSIZE, "%s://%s%s%s%s%s%s%s%s%s%s%s%s%s", equakedata->portname, MAPURL1, equakedata->equakeformat[n].lat, MAPURL2, equakedata->equakeformat[n].lon, MAPURL2, "Earthquake Magnitude: ", equakedata->equakeformat[n].magnitude, " Region: ", equakedata->equakeformat[n].region, MAPURL2, "Rendered by e-quake.org", MAPURL2, WEBSITE);
 
 	/* convert magnitude to double */
         if(equakedata->equakeformat[n].magnitude!=NULL)
@@ -1163,10 +1163,14 @@ static void display_lastperiod(struct Equake_Data *equakedata, int period)
   if (runningweek==NULL)
     return;
 
-  memset(lastday, 0, strlen(lastday));
+  /*memset(lastday, 0, strlen(lastday));
   memset(runningday, 0, strlen(runningday));
   memset(lastweek, 0, strlen(lastweek));
-  memset(runningweek, 0, strlen(runningweek));
+  memset(runningweek, 0, strlen(runningweek));*/
+  memset(lastday, 0, sizeof(lastday));
+  memset(runningday, 0, sizeof(runningday));
+  memset(lastweek, 0, sizeof(lastweek));
+  memset(runningweek, 0, sizeof(runningweek));
     
   char *lasthour=alloca(sizeof(equakedata->buffer)+1); /* there's not more memory needed than what's in the buffer and normally much less */
   if (lasthour==NULL)
@@ -1175,9 +1179,11 @@ static void display_lastperiod(struct Equake_Data *equakedata, int period)
   if (running==NULL)
     return;
 
-  memset(lasthour, 0, strlen(lasthour));
-  memset(running, 0, strlen(running));
-  
+  /*memset(lasthour, 0, strlen(lasthour));
+  memset(running, 0, strlen(running));*/
+  memset(lasthour, 0, sizeof(lasthour));
+  memset(running, 0, sizeof(running));
+ 
   if ((period==DAILY) && (equakedata->quake_history_countdaily<0))
   {
     display_dialog("No data available at this time");
